@@ -1,17 +1,8 @@
 <?php
 
-/**
- * autorespond/lib.php
- * 
- * The primary function library for the SquirrelMail "autorespond" plugin,
- * which allows a user to modify an email forward file and vacation files
- * over FTP, using their IMAP credentials for authentication.
- * 
- * @copyright Copyright (c) 2002-2007 O'Shaughnessy Evans <shaug-spamrule @ wumpus.org>
- * @version $Id: lib.php,v 1.20 2007/09/11 18:52:13 shaug Exp $
- * @license http://opensource.org/licenses/artistic-license-2.0.php
- * @package plugins
- * @subpackage autorespond
+/*
+ * forward:  $Id: lib.php,v 1.15 2007/09/06 21:34:41 root Exp $
+ * (c) 2002 O'Shaughnessy Evans <shaug-spamrule @ wumpus.org>
  */
 
 /*
@@ -29,13 +20,22 @@
  */
 
 
-/**
- * ar_print_header($mesg, $columns)
+// include compatibility plugin
+if (defined('SM_PATH'))
+   include_once(SM_PATH . 'plugins/compatibility/functions.php');
+else if (file_exists('../plugins/compatibility/functions.php'))
+   include_once('../plugins/compatibility/functions.php');
+else if (file_exists('./plugins/compatibility/functions.php'))
+   include_once('./plugins/compatibility/functions.php');
+
+
+/* ar_print_header($mesg, $columns)
  * 
  * Print out the beginning of a table, with $mesg in the first row.
  * 
- * @param string $mesg  text to print out
- * @param int $columns  how many columns will be in the table
+ * Parameters:
+ *   $mesg:     text to print out
+ *   $columns:  how many columns will be in the table
  * 
  * Returns:
  *   nothing
@@ -44,7 +44,7 @@ function ar_print_header($mesg, $columns)
 {
     global $color;
 
-    $title = _("Options") . ' - '. ar_gettext("Automatic Forward and Reply");
+    $title = _("Options") . ' - '. ar_gettext('Automatic Forward and Reply');
 
     echo <<<EOtable_top
 <br>
@@ -59,29 +59,26 @@ function ar_print_header($mesg, $columns)
         <td colspan=$columns>
 EOtable_top;
 
-    if (isset($mesg)) {
+    if (isset($mesg))
         echo "<p>{$mesg}</p>\n";
-    }
 
     echo "</td>\n</tr>\n\n";
 }
 
 
-/**
- * ar_print_footer($mesg, $columns)
+/* ar_print_footer($mesg, $columns)
  * 
  * Print out the end of a table, with $mesg in the last row.
  * 
- * @param string $mesg  text to print out
- * @param int $columns  how many columns the table has
+ * Parameters:
+ *   $mesg:     text to print out
+ *   $columns:  how many columns the table has
  * 
  * Returns:
  *   nothing
  */
 function ar_print_footer($mesg, $columns)
 {
-    global $color;
-
     if (isset($mesg)) {
         echo <<<EOmesg
 
@@ -104,15 +101,15 @@ EOfooter;
 
 
 
-/**
- * ar_ftp_get($path)
+/* ar_ftp_get($path)
  * 
  * Downloads the given file name from the user's account on
  * $AUTORESPOND_OPTS['ftphost'] and returns the contents as an array.
  * 
- * @param string $path  path to the file to be downloaded via FTP
+ * Parameters:
+ *   $path:  path to the file to be downloaded via FTP
  * 
- * @returns array (boolean status, string info)
+ * Returns:
  *   2-element array:
  *   On success, the 1st element will be TRUE and the 2nd will contain a
  *   string with the contents of the requested file.
@@ -121,23 +118,21 @@ EOfooter;
  */
 function ar_ftp_get($path)
 {
-    global $AUTORESPOND_OPTS, $key, $onetimepad, $username;
-    sqgetGlobalVar('AUTORESPOND_OPTS', $AUTORESPOND_OPTS, SQ_SESSION);
+    global $AUTORESPOND_OPTS;
+
     sqgetGlobalVar('key', $key, SQ_COOKIE);
     sqgetGlobalVar('onetimepad', $onetimepad, SQ_SESSION);
     sqgetGlobalVar('username', $username, SQ_SESSION);
 
     $ftphost = $AUTORESPOND_OPTS['ftphost'];
-    if (!$ftphost) {
-        return array(FALSE, ar_gettext("Sorry, but this plugin is not ".
-                            "completely set up.  Please contact your System ".
-                            "Administrator about configuring the Autorespond ".
-                            "plugin."));
-    }
+    if (!$ftphost)
+        return array(FALSE, ar_gettext('Sorry, but this plugin is not '.
+                            'completely set up.  Please contact your System '.
+                            'Administrator about configuring the Autorespond '.
+                            'plugin.'));
 
-    if (empty($path)) {
-        return array(FALSE, ar_gettext("no file was given to upload"));
-    }
+    if (empty($path))
+        return array(FALSE, ar_gettext('no file was given to upload'));
 
     // decrypt the user's password so we can pass it to the ftp site
     $password = OneTimePadDecrypt($key, $onetimepad);
@@ -145,24 +140,18 @@ function ar_ftp_get($path)
 
     // upload the file to the user's home
     $ftp = ftp_connect($ftphost);
-    if (!$ftp) {
-        return array(FALSE, ar_gettext("cannot connect to"). " $ftphost".
-                            ($php_errormsg ? ": $php_errormsg" : ''));
-    }
     $stat = ftp_login($ftp, $username, $password);
-    if (!$stat) {
-        return array(FALSE, ar_gettext("cannot log in to"). " $ftphost".
-                            ($php_errormsg ? ": $php_errormsg" : ''));
+    if (!$ftp or !$stat) {
+        return array(FALSE, ar_gettext('cannot connect to').
+                                       " $ftphost: $php_errormsg");
     }
 
-    if (! @ftp_chdir($ftp, dirname($path))) {
+    if (! @ftp_chdir($ftp, dirname($path)))
         return array(FALSE);
-    }
 
     $file = basename($path);
-    if (! @ftp_size($ftp, $file)) {
+    if (! @ftp_size($ftp, $file))
         return array(FALSE);
-    }
 
     // create a local temp file to store the rules
     $temp = tmpfile();
@@ -185,37 +174,35 @@ function ar_ftp_get($path)
 }
 
 
-/**
- * ar_ftp_put($path, $data)
+/* ar_ftp_put($path, $data)
  * 
  * Uploads the text in $data to $path in the user's account on 
  * $AUTORESPOND_OPTS['ftphost'].
  * 
- * @param string $path  the file to be modified
- * @param string $data  the data to be written to $path; if it's an empty string, $path will be removed
+ * Parameters:
+ *   $path:  (string) the file to be modified
+ *   $data:  (string) the data to be written to $path; if it's an empty
+ *           string, $path will be removed
  * 
  * Returns:
  *   nothing
  */
 function ar_ftp_put($path, $data)
 {
-    global $AUTORESPOND_OPTS, $key, $onetimepad, $username;
-    sqgetGlobalVar('AUTORESPOND_OPTS', $AUTORESPOND_OPTS, SQ_SESSION);
+    global $AUTORESPOND_OPTS;
+
     sqgetGlobalVar('key', $key, SQ_COOKIE);
     sqgetGlobalVar('onetimepad', $onetimepad, SQ_SESSION);
     sqgetGlobalVar('username', $username, SQ_SESSION);
 
     $ftphost = $AUTORESPOND_OPTS['ftphost'];
-    if (!$ftphost) {
-        return array(FALSE, ar_gettext("Sorry, but this plugin is not ".
-                            "completely set up.  Please contact your System ".
-                            "Administrator about configuring the Autorespond ".
-                            "plugin."));
-    }
-
-    if (!$path) {
-        return array(FALSE, ar_gettext("no file was given to upload"));
-    }
+    if (!$ftphost)
+        return array(FALSE, ar_gettext('Sorry, but this plugin is not '.
+                            'completely set up.  Please contact your System '.
+                            'Administrator about configuring the Autorespond '.
+                            'plugin.'));
+    if (!$path)
+        return array(FALSE, ar_gettext('no file was given to upload'));
 
     // decrypt the user's password so we can pass it to the ftp site
     // (borrowed from the vacation plugin; thanks!)
@@ -223,14 +210,10 @@ function ar_ftp_put($path, $data)
 
     // upload the file to the user's home
     $ftp = ftp_connect($ftphost);
-    if (!$ftp) {
-        return array(FALSE, ar_gettext("cannot connect to"). " $ftphost".
-                            ($php_errormsg ? ": $php_errormsg" : ''));
-    }
     $stat = ftp_login($ftp, $username, $password);
-    if (!$stat) {
-        return array(FALSE, ar_gettext("cannot log in to"). " $ftphost".
-                            ($php_errormsg ? ": $php_errormsg" : ''));
+    if (!$ftp or !$stat) {
+        return array(FALSE, ar_gettext('cannot connect to').
+                                       " $ftphost: $php_errormsg");
     }
     // if there is data to upload, write it to a temporary file and upload
     // its contents
@@ -245,23 +228,18 @@ function ar_ftp_put($path, $data)
         $dir = dirname($path);
         $dirs = preg_split('/[\\/\\\]+/', $dir, -1, PREG_SPLIT_NO_EMPTY);
         foreach ($dirs as $d) {
-            if ($d == '.') {
-                continue;
-            }
-            if ($d == '/') {
-                continue;
-            }
+            if ($d == '.') continue;
+            if ($d == '/') continue;
             if (! @ftp_chdir($ftp, $d)) {
                 if (!(@ftp_mkdir($ftp, $d) && @ftp_site($ftp, "chmod 0700 $d")
                      && @ftp_chdir($ftp, $d))) {
-                    return array(FALSE, ar_gettext("error creating"). " $dir".
-                                 ($php_errormsg ? ": $php_errormsg" : ''));
+                    return array(FALSE, ar_gettext('error creating').
+                                                   " $dir: $php_errormsg");
                 }
             }
         }
-
-        $cwd = ftp_pwd($ftp);
         /*
+        $cwd = ftp_pwd($ftp);
         if ($cwd != "/" and $cwd != $dir and $cwd != "/$dir") {
             return array(FALSE, "error creating $dir (could only get to ".
                             "$cwd): $php_errormsg");
@@ -270,22 +248,18 @@ function ar_ftp_put($path, $data)
 
         $file = basename($path);
         $stat = ftp_fput($ftp, $file, $temp, FTP_ASCII);
-        if (!$stat) {
-            @ftp_close($ftp);
-            return array(FALSE, ar_gettext("error changing"). " $cwd/$file".
-                                ($php_errormsg ? ": $php_errormsg" : ''));
-        }
+        if (!$stat)
+            return array(FALSE, ar_gettext('error changing').
+                                           " $cwd/$file: $php_errormsg");
         @ftp_site($ftp, "chmod 0600 $file");
         fclose($temp);
     }
     // otherwise delete the remote file (we don't want to leave an empty file)
     else {
         $stat = @ftp_delete($ftp, $path);
-        if (!$stat) {
-            @ftp_close($ftp);
-            return array(FALSE, ar_gettext("error removing"). " $path".
-                                ($php_errormsg ? ": $php_errormsg" : ''));
-        }
+        if (!$stat)
+            return array(FALSE, ar_gettext('error removing').
+                                           " $path: $php_errormsg");
     }
 
     @ftp_quit($ftp);
@@ -294,12 +268,12 @@ function ar_ftp_put($path, $data)
 }
 
 
-/**
- * ar_syslog($message)
+/* ar_syslog($message)
  * 
  * Write a message to the syslog.
  * 
- * @param string $message  text to send
+ * Parameters:
+ *   $mesg:     text to send
  * 
  * Returns:
  *   nothing
@@ -313,15 +287,16 @@ function ar_syslog($message)
 }
 
 
-/**
- * ar_gettext($str)
+/* ar_gettext($str)
  * 
  * Switch the gettext domain to autorespond's before reading the localized
  * version of astring, then switch the translation domain back to squirrelmail
  * 
- * @param string $str  string to be translated
+ * Parameters:
+ *   $str:  string to be translated
  * 
- * @returns string containing gettext-translated text
+ * Returns:
+ *   string containing gettext-translated text
  */
 function ar_gettext($str)
 {
@@ -338,9 +313,7 @@ function ar_gettext($str)
     return $localstr;
 }
 
-
-/**
- * ar_change_autoresponse()
+/* ar_change_autoresponse()
  * 
  * Prints out a form allowing the user to change various options for
  * processing new mail (typically the things you might want to do in a
@@ -365,12 +338,12 @@ function ar_gettext($str)
  */
 function ar_change_autoresponse()
 {
-    global $AUTORESPOND_OPTS, $color, $trash_folder;
-    sqgetGlobalVar('AUTORESPOND_OPTS', $AUTORESPOND_OPTS, SQ_SESSION);
-    sqgetGlobalVar('trash_folder', $trash_folder, SQ_FORM);
+    global $AUTORESPOND_OPTS, $color;
+    sqgetGlobalVar('trash_folder', $trash_folder);
 
     $addrs = array();
     $aliases = '';
+    $files = array();
     $check_fwd = '';
     $check_keep = '';
     $check_trash = '';
@@ -379,25 +352,18 @@ function ar_change_autoresponse()
     $keep_filt = '';
 
     // download and process the installed forward file
-    list($stat, $forward) = ar_ftp_get($AUTORESPOND_OPTS['forward_file']);
-    if ($stat === FALSE) {
-        print ar_gettext("There was a problem connecting to your FTP server:").
-              '&nbsp;&nbsp;'. ($forward ? "\"$forward\".&nbsp;&nbsp;" : '').
-              ar_gettext("Please contact your support department."). "<br>\n";
-    }
-    else if (! empty($forward)) {
-        foreach ($forward as $line) {
+    list($status, $forward) = ar_ftp_get($AUTORESPOND_OPTS['forward_file']);
+    if ($status === TRUE && ! empty($forward)) {
+        foreach ($forward as $i => $line) {
             $line = trim($line);
             // skip if the line is empty
-            if (!$line) {
+            if (!$line)
                 continue;
-            }
 
             // if it looks like a disabled forward that we created
             // earlier, remember it as the default forward address
-            $matches = array();
-            if (@ereg('^# forward: *([^ ].*)', $line, $matches)) {
-                array_push($addrs, $matches[1]);
+            if (@ereg('^# forward: *([^ ].*)', $line, $regs)) {
+                array_push($addrs, $regs[1]);
                 continue;
             }
             // skip other comments
@@ -411,19 +377,16 @@ function ar_change_autoresponse()
             $splitline = preg_split('/\s*,\s*/', $line);
             foreach ($splitline as $f) {
                 // if the forward entry is a path,
-                // either it's being put into the Trash
-                // or we will presume that means a local copy is being kept
-                $matches = array();
-                // does the line look like a path?
-                if (@preg_match('/^[\.\/\\\\]\S+/', $f, $matches)) {
-                    // now see if the end matches our trash_folder
-                    if (strpos(strrev($matches[0]), strrev($trash_folder))
-                        === 0) {
+                // either it's being put into the Trash or
+                // we will presume that means a local copy is being kept
+                if (@ereg('^([\.\/\\][^ ]*)', $f, $regs)) {
+                    if (@ereg("$trash_folder$", $regs[1])) {
                         $check_trash = 'checked';
                     }
                     else {
                         $keep_nofilt = $check_keep = 'checked';
                         $keep_filt = '';
+                        //array_push($files, $regs[1]);
                     }
                 }
                 // if it matches our vacation regex, turn on
@@ -488,19 +451,17 @@ function ar_change_autoresponse()
     }
 
     list($subject, $message) = ar_read_vacation();
-    if (!$subject) {
+    if (!$subject)
         $subject = $AUTORESPOND_OPTS['default_subject'];
-    }
-    if (!$message) {
+    if (!$message)
         $message = $AUTORESPOND_OPTS['default_message'];
-    }
 
     echo <<<EOform_top
 <tr bgcolor="{$color[12]}">
   <td colspan=3><form action="options.php" method=GET>
 EOform_top;
 
-    print '<b>'. ar_gettext("You can choose one or more of these options:").
+    print '<b>'. ar_gettext('You can choose one or more of these options:').
           "</br>\n";
 
     echo <<<EOform_top
@@ -576,22 +537,15 @@ EOcache;
 EOvacation;
     }
 
-    // show the "keep a local copy" checkboxes:
-    // In $AUTORESPOND_OPTS, we check whether keep_desc is set.  This will
-    // enable the whole form section that lets a user enable storing their
-    // mail locallly, either via the keep_string method (typically "\username"
-    // in a .forward file) or the filter_string method (typically a pipe to
-    // procmail or maildrop).  If filter_string is defined, we show radio
-    // boxes allowing the user to choose whether to filter or not; if it's not
-    // defined, we don't show the radio boxes and assume the keep_string is
-    // defined to allow the user to enable local retention w/o filtering.
+    // show the "keep a local copy" checkboxes
     $desc = $AUTORESPOND_OPTS['keep_desc'];
     if ($desc) {
-        $unfilt_label = ar_gettext("unfiltered");
-        $filt_label = ar_gettext("filtered");
-        $check_label = ar_gettext("Keep a copy here?");
+        $unfilt_label = ar_gettext('unfiltered');
+        $filt_label = ar_gettext('filtered');
+        $check_label = ar_gettext('Keep a copy here?');
         $keep_text = isset($AUTORESPOND_OPTS['filter_string'])
-         ? '<input type=radio name=keeptype value=unfiltered '.$keep_nofilt.'>'.
+         ? '&nbsp;&nbsp;'. $AUTORESPOND_OPTS['keep_filt_desc']. "<br><br>\n".
+           '<input type=radio name=keeptype value=unfiltered '.$keep_nofilt.'>'.
            "<i>$unfilt_label</i>&nbsp;&nbsp;\n".
            '<input type=radio name=keeptype value=filtered '. $keep_filt. '>'.
            "<i>$filt_label</i>\n"
@@ -600,7 +554,7 @@ EOvacation;
     <tr align=left valign=top bgcolor="{$color[4]}">
       <td><input type=checkbox name=keep $check_keep></td>
       <td><b>$check_label</b></td>
-      <td>$desc<br><br>
+      <td>$desc
         $keep_text
       </td>
     </tr>
@@ -611,7 +565,7 @@ EOkeep;
     // show the "send it to the Trash" option
     $desc = $AUTORESPOND_OPTS['trash_desc'];
     if ($desc) {
-        $check_label = ar_gettext("Sent it to your Trash?");
+        $check_label = ar_gettext('Sent it to your Trash?');
         echo <<<EOkeep
 <tr align=left valign=top bgcolor="{$color[12]}">
   <td><input type=checkbox name=trash $check_trash></td>
@@ -624,7 +578,7 @@ EOkeep;
     }
 
     // close out the form
-    $finish_label = ar_gettext("Finish");
+    $finish_label = ar_gettext('Finish');
     echo <<<EOend
     <tr align=left>
       <td align=left colspan=3> 
@@ -638,8 +592,7 @@ EOend;
 }
 
 
-/**
- * ar_install_autoresponse()
+/* ar_install_autoresponse()
  * 
  * Reads the data submitted by the autoresponse options form and
  * installs it all in the user's forward and vacation files via FTP,
@@ -659,32 +612,29 @@ EOend;
  */
 function ar_install_autoresponse()
 {
-    global $AUTORESPOND_OPTS, $color, $addr, $aliases, $forward, $keep,
-           $reset_cache, $trash, $trash_folder, $vacation;
-    sqgetGlobalVar('AUTORESPOND_OPTS', $AUTORESPOND_OPTS, SQ_SESSION);
-    sqgetGlobalVar('addr', $addr, SQ_FORM);
-    sqgetGlobalVar('aliases', $aliases, SQ_FORM);
-    sqgetGlobalVar('forward', $forward, SQ_FORM);
-    sqgetGlobalVar('keep', $keep, SQ_FORM);
-    sqgetGlobalVar('reset_cache', $reset_cache, SQ_FORM);
-    sqgetGlobalVar('trash', $trash, SQ_FORM);
-    sqgetGlobalVar('trash_folder', $trash_folder);
-    sqgetGlobalVar('vacation', $vacation, SQ_FORM);
+    global $AUTORESPOND_OPTS, $color;
     $data = '';
 
+    sqgetGlobalVar('addr', $addr);
+    sqgetGlobalVar('aliases', $aliases);
+    sqgetGlobalVar('forward', $forward);
+    sqgetGlobalVar('keep', $keep);
+    sqgetGlobalVar('reset_cache', $reset_cache);
+    sqgetGlobalVar('trash', $trash);
+    sqgetGlobalVar('trash_folder', $trash_folder);
+    sqgetGlobalVar('vacation', $vacation);
+
     if ($addr) {
         if ($forward) {
             $data = "$addr\n";
-            $mesg = ar_gettext("New mail will be sent to"). ' '.
-                    '<a href="mailto:'. htmlspecialchars($addr).
-                    '"><i>'. htmlspecialchars($addr). '</i></a>.';
+            $mesg = ar_gettext('New mail will be sent to'). ' '.
+                    "<a href=\"mailto:$addr\"><i>$addr</i></a>.";
         }
         else
             $data = "# forward: $addr\n";
     }
-    if (!$forward) {
-        $mesg = ar_gettext("New mail will be kept here in your Inbox.");
-    }
+    if (!$forward)
+        $mesg = ar_gettext('New mail will be kept here in your Inbox.');
 
     // build up a list of vacation command options for each alias provided
     // by the form, then create the vacation command string from this
@@ -701,8 +651,8 @@ function ar_install_autoresponse()
         if (sizeof($alias_list) > 0) {
             foreach ($alias_list as $alias_addr) {
                 if (preg_match('/^\S+$/', $alias_addr)) {
-                    $mesg .= "<br>\n... ". htmlspecialchars($alias_addr). ' '.
-                             ar_gettext("is recognized as an alias.");
+                    $mesg .= "<br>\n... $alias_addr ".
+                             ar_gettext('is recognized as an alias.');
                     $alias_opts .=
                                sprintf($AUTORESPOND_OPTS['vacation_alias'],
                                $alias_addr);
@@ -718,61 +668,29 @@ function ar_install_autoresponse()
         }
     }
 
-    // if the vacation feature was enabled, recreate the vacation_file
-    // and upload it, then append the vacation_string to the forward data
+    // recreate the vacation_file and upload it if requested,
+    // then append the vacation_string to the forward data
     if ($vacation) {
-        sqgetGlobalVar('message', $message, SQ_FORM);
-        sqgetGlobalVar('subject', $subject, SQ_FORM);
-        $vacdata = '';
-
-        // build up the new vacation message file in $vacdata:
-        // from and subject headers, then a newline and the message body.
-
-        // include a From header in the vacation message derived from
-        // the address the user has defined in squirrelmail's prefs.
-        // this can be disabled by changing the vacation_from config var
-        // to FALSE.  this is necessary for platforms where vacation
-        // doesn't support a From header (e.g. Solaris 8 & before)
-        if ($AUTORESPOND_OPTS['vacation_from'] !== FALSE) {
-            $name = getPref($data_dir, $username, 'full_name');
-            $email = getPref($data_dir, $username, 'email_address');
-            if (!empty($name) && !empty($email)) {
-                $vacdata .= "From: $name <$email>\n";
-            }
-        }
-
-        $vacdata .= "Subject: ". $subject. "\n\n". $message;
-
-        // convert <return><newline> to <newline> in the vacation file
-        // because the form may pass it to us with the extra returns
+        sqgetGlobalVar('message', $message);
+        sqgetGlobalVar('subject', $subject);
+        $vacdata = "Subject: ". $subject. "\n\n". $message;
         $vacdata = str_replace("\r\n", "\n", $vacdata);
-
-        // ensure the new vacation file ends with a newline
-        if (! @ereg("\n$", $vacdata)) {
+        if (! @ereg("\n$", $vacdata))
             $vacdata .= "\n";
-        }
-
         list($stat, $ftpmesg) = ar_ftp_put($AUTORESPOND_OPTS['vacation_file'],
          $vacdata);
-        if ($stat === FALSE) {
-            print ar_gettext("There was a problem uploading your vacation ".
-                             "file:").
-                  '&nbsp;&nbsp;'. ($ftpmesg ? "\"$ftpmesg\".&nbsp;&nbsp;" : '').
-                  ar_gettext("Please contact your support department.").
-                  "<br>\n";
-        }
         $data .= sprintf($AUTORESPOND_OPTS['vacation_string'], $alias_opts).
                  "\n";
 
-        $mesg .= "<br>\n". ar_gettext("Senders will get an automatic reply.");
+        $mesg .= "<br>\n". ar_gettext('Senders will get an automatic reply.');
     }
     else {
-        $mesg .= "<br>\n". ar_gettext("No automatic reply will be sent.");
+        $mesg .= "<br>\n". ar_gettext('No automatic reply will be sent.');
     }
 
     // empty out the user's vacation reply cache if requsted
     if ($reset_cache) {
-        $mesg .= "<br>\n". ar_gettext("Your reply cache has been reset.");
+        $mesg .= "<br>\n". ar_gettext('Your reply cache has been reset.');
         // use FTP to remove the vacation_cache file from the user's account
         ar_ftp_put($AUTORESPOND_OPTS['vacation_cache'], '');
     }
@@ -780,25 +698,22 @@ function ar_install_autoresponse()
     // if the user requested to keep local mail, build up a filter_string
     // or keep_string and add it to the forward file data
     if ($keep) {
-        sqgetGlobalVar('keeptype', $keeptype, SQ_FORM);
+        sqgetGlobalVar('keeptype', $keeptype);
         if ($keeptype === 'filtered') {
             $data = $AUTORESPOND_OPTS['filter_string']. "\n" . $data;
-            if ($addr) {
-                $mesg .= "<br>\n". ar_gettext("Local copies will also be kept ".
-                         "(and will be filtered through"). ' '.
+            if ($addr)
+                $mesg .= "<br>\n". ar_gettext('Local copies will also be kept '.
+                         '(and will be filtered through'). ' '.
                          $AUTORESPOND_OPTS['filter_descr']. ").";
-            }
-            else {
-                $mesg .= "<br>\n..." . ar_gettext("filtered through"). ' '.
+            else
+                $mesg .= "<br>\n..." . ar_gettext('filtered through'). ' '.
                          $AUTORESPOND_OPTS['filter_descr']. '.';
-            }
         }
         else {
             $data = $AUTORESPOND_OPTS['keep_string']. "\n" . $data;
-            if ($addr) {
+            if ($addr)
                 $mesg .= "<br>\n".
-                         ar_gettext("Local copies will also be kept.");
-            }
+                         ar_gettext('Local copies will also be kept.');
         }
     }
 
@@ -807,19 +722,13 @@ function ar_install_autoresponse()
         $trash = @ereg('^[\.\/\\]', $trash_folder) ? $trash_folder
                  : "./$trash_folder";
         $mesg .= "<br>\n".
-                 ar_gettext("Mail will be kept in your Trash mailbox.");
+                 ar_gettext('Mail will be kept in your Trash mailbox.');
         $data .= $trash. "\n";
     }
 
     // upload the new forward file with all the commands that we just
     // put together
-    list ($stat, $ftpmesg) = ar_ftp_put($AUTORESPOND_OPTS['forward_file'],
-                                        $data);
-    if ($stat === FALSE) {
-        print ar_gettext("There was a problem uploading your forward file:").
-              '&nbsp;&nbsp;'. ($ftpmesg ? "\"$ftpmesg\".&nbsp;&nbsp;" : '').
-              ar_gettext("Please contact your support department."). "<br>\n";
-    }
+    ar_ftp_put($AUTORESPOND_OPTS['forward_file'], $data);
 
     // tell the user what features were just activated
     echo <<<EOmesg
@@ -828,7 +737,7 @@ function ar_install_autoresponse()
       <td>&nbsp;</td>
       <td><b>
 EOmesg;
-    print ar_gettext("New settings saved:"). "</b></td>\n";
+    print ar_gettext('New settings saved:'). "</b></td>\n";
     echo <<<EOmesg
       <td><font color=green>$mesg</font></td>
     </tr>
@@ -839,47 +748,30 @@ EOmesg;
 }
 
 
-/**
- * ar_read_vacation()
+/* ar_read_vacation()
  * 
- * Load the user's vacation message via FTP.
- * 
- * @returns array:  (string subject, string message body (individual lines joined together by newlines))
+ * Load the user's vacation message via FTP.  Returns an array with the
+ * Subject message as the first index and the body of the message as the
+ * second.  The message body is a single string with all the lines joined
+ * together, separated within the string by newlines.
  */
 function ar_read_vacation()
 {
     global $AUTORESPOND_OPTS;
-    sqgetGlobalVar('AUTORESPOND_OPTS', $AUTORESPOND_OPTS, SQ_SESSION);
     $subject = '';
     $message = '';
 
     // download and process the installed vacation message
-    list($stat, $vacation) = ar_ftp_get($AUTORESPOND_OPTS['vacation_file']);
-    if ($stat === FALSE) {
-        print ar_gettext("There was a problem connecting to your FTP server:").
-              '&nbsp;&nbsp;'. ($vacation ? "\"$vacation\".&nbsp;&nbsp;" : '').
-              ar_gettext("Please contact your support department."). "<br>\n";
-    }
-    else if ($stat === TRUE && !empty($vacation)) {
-        // Look for headers at the beginning of the file and strip them out.
-        // If we find the subject, store it to return to the calling function.
-        // The rest of the file is the message body, returned as a string
-        // of joined lines.
-        $hdr = array();
-
-        while (preg_match('/^(\S+):\s+(.*)/', $vacation[0], $hdr)) {
-            if (!strcasecmp($hdr[1], 'Subject')) {
-                $subject = $hdr[2];
-            }
+    list($status, $vacation) = ar_ftp_get($AUTORESPOND_OPTS['vacation_file']);
+    if ($status === TRUE && !empty($vacation)) {
+        // if the vacation entry looks like an email Subject,
+        // save it for the default
+        if (@ereg('^Subject: (.*)', $vacation[0], $regs)) {
+            $subject = $regs[1];
             array_shift($vacation);
             reset($vacation);
-        }
-
-        // if we stripped headers, the vacation may still have a leading
-        // newline or return/newline that needs to be stripped
-        if (@ereg("^\r?\n?$", $vacation[0])) {
-            array_shift($vacation);
-
+            if (@ereg("^\r?\n?$", $vacation[0]))
+                array_shift($vacation);
         }
         $message = implode('', $vacation);
     }
@@ -888,8 +780,7 @@ function ar_read_vacation()
 }
 
 
-/**
- * ar_edit_vacation()
+/* ar_edit_vacation()
  * 
  * Function unused at present, but designed to allow a popup or otherwise
  * standalone window to edit a vacation file.  Provides a form with inputs
@@ -903,43 +794,33 @@ function ar_read_vacation()
  */
 function ar_edit_vacation()
 {
-    global $AUTORESPOND_OPTS, $color, $message, $subject;
-    sqgetGlobalVar('message', $message, SQ_FORM);
-    sqgetGlobalVar('subject', $subject, SQ_FORM);
+    global $AUTORESPOND_OPTS, $color;
+
+    sqgetGlobalVar('message', $message);
+    sqgetGlobalVar('subject', $subject);
 
     // if a message and subject weren't defined already (can this ever happen?),
     // we need to read them from the user's vacation file
     //
     // if they were set, then we need to build up a new vacation file message
     // and upload it to the account's home via ftp
-    if (!$subject && !$message) {
+    if (!$subject && !$message)
         list($subject, $message) = ar_read_vacation();
-    }
     else {
-        if (! @ereg("\n$", $message)) {
+        if (! @ereg("\n$", $message))
             $message .= "\n";
-        }
         $data = "Subject: $subject\n\n". $message;
         $data = str_replace("\r\n", "\n", $data);
         list($stat, $ftpmesg) = ar_ftp_put($AUTORESPOND_OPTS['vacation_file'],
          $data);
-        if ($stat === FALSE) {
-            print ar_gettext("There was a problem uploading your vacation ".
-                  "file:").
-                  '&nbsp;&nbsp;"'. $ftpmesg. "\".&nbsp;&nbsp;";
-                  ar_gettext("Please contact your support department.").
-                  "<br>\n";
-        }
     }
 
     // set vacation subject and message defaults based on predefined values
     // if they weren't passed through a form or loaded from the vacation file
-    if (!$subject) {
+    if (!$subject)
         $subject = $AUTORESPOND_OPTS['default_subject'];
-    }
-    if (!$message) {
+    if (!$message)
         $message = $AUTORESPOND_OPTS['default_message'];
-    }
 
     $subj_label = ar_gettext("Subject:");
     $mesg_label = ar_gettext("Message:");
